<?php

/*
 * class.exceptions.php
 *
 * @software  Except - General Exception Class
 * @author    James Brumond
 *
 * Copyright 2010 James Brumond
 * Dual licensed under MIT and GPL
 */

// make sure that the library is not being called directly
if (__FILE__ == $_SERVER["SCRIPT_FILENAME"]) die("Bad Load Order");



define("EXCEPT_STOP_MESSAGE", 0);
define("EXCEPT_STOP_WARNING", 1);
define("EXCEPT_STOP_CRITICAL", 3);



/*
 * @class   ExceptException
 * @parent  Exception
 */
class ExceptException extends Exception { }



/*
 * @class   Except
 * @parent  void
 */
class Except {

	protected $exceptions = true;
	protected $html_exceptions = true;

	public function throw_exception($msg = 'unknown exception', $level = EXCEPT_STOP_WARNING) {
		try {
			throw new ExceptException($msg, $level);
		} catch (ExceptException $e) {
			$this->handle_exception($e);
		}
	}
	
	public function display($flag) {
		$this->exceptions = !!$flag;
	}
	
	public function display_html($flag) {
		$this->html_exceptions = !!$flag;
	}

	protected function handle_exception($e) {
		// figure out the type of exception
		switch ($e->getCode()) {
			case EXCEPT_STOP_MESSAGE:     # 0
			case E_NOTICE:             # 8 (built-in)
			case E_USER_NOTICE:        # 1024 (built-in)
				$type = 'Notice';
				$return = true;
				break;
			case EXCEPT_STOP_WARNING:     # 1
			case E_WARNING:            # 2 (built-in)
			case E_USER_WARNING:       # 512 (built-in)
				$type = 'Warning';
				$return = true;
				break;
			case EXCEPT_STOP_CRITICAL:    # 3
			case E_USER_ERROR:         # 256 (built-in)
				$type = 'Error';
				$return = false;
				break;
			case E_RECOVERABLE_ERROR:  # 4096 (built-in)
				$type = 'Recoverable Error';
				$return = true;
				break;
			default:
				$type = 'Unknown Type Exception';
				$return = false;
				break;
		}

		if ($this->exceptions) {
			// get some useful information
			$info = $e->getTrace();
			$info = $info[count($info) - 1];

			// echo the exception using html or not?
			if ($this->html_exceptions) {
				$msg = '<strong>' . $type . '</strong>: ' . $e->getMessage() . ' in <strong>' . $info['file'] .
				'</strong> on line <strong>' . $info['line'] . '</strong><br />' . "\n";
			} else {
				$msg = $type . ': ' . $e->getMessage() . ' in ' . $info['file'] . ' on line ' . $info['line'] . "\n";
			}

			// echo the message
			echo $msg;
		}

		if (! $return) die();
		return $return;
	}

}

?>
